﻿using Microsoft.Win32;
using System.IO;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace GraphicalObjectFile
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private List<GraphicalObject> graphicalObjects = new List<GraphicalObject>();
        public MainWindow()
        {
            InitializeComponent();
        }

        private void NewItem_Click(object sender, RoutedEventArgs e)
        {
            graphicalObjects.Clear();
            RefreshUI();
        }

        private void RefreshUI()
        {
            DataView.Items.Clear();
            foreach(GraphicalObject graphicalObject in graphicalObjects)
            {
                DataView.Items.Add(graphicalObject);
            }
            ObjectsCount.Content = graphicalObjects.Count;
        }

        private void OpenItem_Click(object sender, RoutedEventArgs e)
        {
            OpenFileDialog dialog = new OpenFileDialog();
            if(dialog.ShowDialog() == true )
            {
                LoadData(dialog.FileName);
                RefreshUI();
            }
        }

        private void LoadData(string filename)
        {
            using(StreamReader reader= new StreamReader(filename))
            {
                GraphicalObject graphicalObject = null;
                string line = null;
                while ((line = reader.ReadLine()) != null)
                {
                    try
                    {
                        graphicalObject = GraphicalObject.parse(line);
                        graphicalObjects.Add(graphicalObject);
                    }catch(FormatException ex)
                    {
                        MessageBox.Show("Neplatny format souboru: " + ex.Message);
                    }
                }
            }
        }

        private void SaveItem_Click(object sender, RoutedEventArgs e)
        {
            SaveFileDialog dialog = new SaveFileDialog();
            if (dialog.ShowDialog() == true)
            {
                SaveData(dialog.FileName);
            }
        }

        private void SaveData(string filename)
        {
            using(StreamWriter writer= new StreamWriter(filename))
            {
                foreach(GraphicalObject obj in  graphicalObjects)
                {
                    writer.WriteLine(obj.ToString());
                }
            }
        }

        private void ExitItem_Click(object sender, RoutedEventArgs e)
        {
            Application.Current.Shutdown();
        }

        private void AddItem_Click(object sender, RoutedEventArgs e)
        {
            AddEntityDialog dialog= new AddEntityDialog();
            if(dialog.ShowDialog() == true)
            {
                graphicalObjects.Add(dialog.GraphicalEntity);
                RefreshUI();
            }
        }

        private void RemoveItem_Click(object sender, RoutedEventArgs e)
        {
            if (DataView.SelectedIndex == -1)
            {
                MessageBox.Show("Musite si vybrat polozku, kterou chcete odebrat.");
                return;
            }
            graphicalObjects.RemoveAt(DataView.SelectedIndex);
            RefreshUI();
        }
    }
}